@@ -1,7 +1,7 @@
 #
 # exceptions.py
 #
-# Copyright (C) 2017-2020 frnmst (Franco Masotti) <franco.masotti@live.com>
+# Copyright (C) 2017-2020 Franco Masotti (franco \D\o\T masotti {-A-T-} tutanota \D\o\T com)
 #
 # This file is part of md-toc.
 #
@@ -39,3 +39,11 @@ class StdinIsNotAFileToBeWritten(Exception):
 
 class TocDoesNotRenderAsCoherentList(Exception):
     """TOC list indentations are either wrong or not what the user intended."""
+
+
+class StringCannotContainNewlines(Exception):
+    """The specified string cannot contain newlines."""
+
+
+class CannotTreatUnicodeString(Exception):
+    """Cannot treat unicode string."""
